@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "playerentity.h"
@@ -27,7 +24,7 @@ PlayerEntity::PlayerEntity(Sea::Player player, Sea* sea, SeaView* view, ChatWidg
 Ship* PlayerEntity::nextShip()
 {
     if (m_ships.empty()) {
-        return 0;
+        return nullptr;
     }
     else {
         return m_ships.first();
@@ -45,14 +42,14 @@ Ship* PlayerEntity::canAddShip(const Coord& c)
             if (m_level == COMPAT_KBS3) {
                 for (unsigned int i = 0; i < ship->size(); i++) {
                     if (m_sea->isNearShip(m_player, c + ship->increment() * i)) {
-                        return 0;
+                        return nullptr;
                     }
                 }
             }
             return ship;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -79,11 +76,11 @@ void PlayerEntity::action(Sea::Player player, const Coord& c)
                             // when multiple ships and an space between them are enabled,
                             // it is possible to reach impossible combinations
                             if ( !m_sea->canAddShipOfSize(m_player, ship->size()) ) {
-                                emit restartPlacingShips(m_player);
+                                Q_EMIT restartPlacingShips(m_player);
                             }
                         }
                         else {
-                            emit shipsPlaced();
+                            Q_EMIT shipsPlaced();
                         }
                     }
                 }
@@ -91,7 +88,7 @@ void PlayerEntity::action(Sea::Player player, const Coord& c)
             break;
         case Sea::PLAYING:
             if (player == opponent && m_sea->canHit(m_player, c)) {
-                emit shoot(m_player, c);
+                Q_EMIT shoot(m_player, c);
             }
             break;
         default:
@@ -125,7 +122,7 @@ void PlayerEntity::startPlacing()
 void PlayerEntity::start()
 {
     UIEntity::start();
-    emit ready(m_player);
+    Q_EMIT ready(m_player);
 }
 
 void PlayerEntity::startPlaying()
